"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("mocha");
var sinon = require("sinon");
var chai_1 = require("chai");
var logger_1 = require("./logger");
describe('Logger', function () {
    var sandbox = sinon.createSandbox();
    afterEach(function () {
        sandbox.restore();
    });
    it('logger.level should be set to "info" if not provided', function () {
        var logger = new logger_1.Logger();
        chai_1.expect(logger.level).to.equal(2);
    });
    it('logger.level should be set to "info" if not invalid level provided', function () {
        var logger = new logger_1.Logger("INVALID");
        chai_1.expect(logger.level).to.equal(2);
    });
    it('logger should not output if level is less than loggers log-level', function () {
        var logger = new logger_1.Logger();
        var stub = sandbox.stub(logger.console, 'log');
        logger.log('test');
        chai_1.expect(stub.called).to.be.false;
    });
    it('logger should write to console', function () {
        var logger = new logger_1.Logger();
        var stub = sandbox.stub(logger.console, 'log');
        logger.log('test', 1);
        chai_1.expect(stub.called).to.be.true;
    });
});
//# sourceMappingURL=logger.spec.js.map